==> gym_cas-0.0.5.tar.gz: gym_cas-0.0.5/src/gym_cas/trigonometry.py <==
from sympy import cos, sin, tan, acos, asin, atan, pi, N

def Sin(v: float):
    '''
    Hjælpefunktion til at udregne sinus til vinklen i grader.

    Brug sin fra sympy hvis der skal arbejdes med udtrykket (fx differentieres).
    '''
    return N(sin(v / 180 * pi))

def Cos(v: float):
    '''
    Hjælpefunktion til at udregne cosinus til vinklen i grader.

    Brug cos fra sympy hvis der skal arbejdes med udtrykket (fx differentieres).
    '''
    return N(cos(v / 180 * pi))


def Tan(v: float):
    '''
    Hjælpefunktion til at udregne tangens til vinklen i grader.

    Brug tan fra sympy hvis der skal arbejdes med udtrykket (fx differentieres).
    '''
    return N(tan(v / 180 * pi))

def aSin(val: float):
    '''
    Hjælpefunktion til at udregne invers sinus til sinusværdien.

    Brug asin fra sympy hvis der skal arbejdes med udtrykket (fx differentieres).
    '''
    return N(asin(val) / pi * 180)

def aCos(val: float):
    '''
    Hjælpefunktion til at udregne invers cosinus til cosinusværdien.

    Brug acos fra sympy hvis der skal arbejdes med udtrykket (fx differentieres).
    '''
    return N(acos(val) / pi * 180)


def aTan(val: float):
    '''
    Hjælpefunktion til at udregne invers tangens til tangensværdien.

    Brug atan fra sympy hvis der skal arbejdes med udtrykket (fx differentieres).
    '''
    return N(atan(val) / pi * 180)

if __name__ == "__main__":
    print(Sin(90))
    print(Sin(135))
    print(Sin(180))
    print(Cos(90))
    print(Cos(135))
    print(Cos(180))
    print(Tan(90))
    print(Tan(135))
    print(Tan(180))
    print(aSin(1))
    print(aSin(0.5))
    print(aSin(-1))
    print(aCos(1))
    print(aCos(0.5))
    print(aCos(-1))
    print(aTan(2))
    print(aTan(1))
    print(aTan(-0.5))

==> gym_cas-0.0.16.tar.gz: gym_cas-0.0.16/src/gym_cas/trigonometry.py <==
# type: ignore
from sympy import cos, sin, tan, acos, asin, atan, pi, Symbol

def Sin(v: float | Symbol):
    '''
    Hjælpefunktion til at udregne sinus til vinklen i grader.

    Brug sin fra sympy hvis der skal arbejdes med udtrykket (fx differentieres).
    '''
    return (sin(v / 180 * pi)).evalf()

def Cos(v: float | Symbol):
    '''
    Hjælpefunktion til at udregne cosinus til vinklen i grader.

    Brug cos fra sympy hvis der skal arbejdes med udtrykket (fx differentieres).
    '''
    return (cos(v / 180 * pi)).evalf()


def Tan(v: float | Symbol):
    '''
    Hjælpefunktion til at udregne tangens til vinklen i grader.

    Brug tan fra sympy hvis der skal arbejdes med udtrykket (fx differentieres).
    '''
    return (tan(v / 180 * pi)).evalf()

def aSin(val: float | Symbol):
    '''
    Hjælpefunktion til at udregne invers sinus til sinusværdien.

    Brug asin fra sympy hvis der skal arbejdes med udtrykket (fx differentieres).
    '''
    return (asin(val) / pi * 180).evalf()

def aCos(val: float | Symbol):
    '''
    Hjælpefunktion til at udregne invers cosinus til cosinusværdien.

    Brug acos fra sympy hvis der skal arbejdes med udtrykket (fx differentieres).
    '''
    return (acos(val) / pi * 180).evalf()


def aTan(val: float | Symbol):
    '''
    Hjælpefunktion til at udregne invers tangens til tangensværdien.

    Brug atan fra sympy hvis der skal arbejdes med udtrykket (fx differentieres).
    '''
    return (atan(val) / pi * 180).evalf()

if __name__ == "__main__":
    print(Sin(90))
    print(Sin(135))
    print(Sin(180))
    print(Cos(90))
    print(Cos(135))
    print(Cos(180))
    print(Tan(90))
    print(Tan(135))
    print(Tan(180))
    print(aSin(1))
    print(aSin(0.5))
    print(aSin(-1))
    print(aCos(1))
    print(aCos(0.5))
    print(aCos(-1))
    print(aTan(2))
    print(aTan(1))
    print(aTan(-0.5))
